==> haskell-executable-path-0.0.3.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 executable-path
version:              0.0.3.1
visibility:           public
id:                   executable-path-0.0.3.1-K1paw4SCDvS8wuNA9ltaVf
key:                  executable-path-0.0.3.1-K1paw4SCDvS8wuNA9ltaVf
license:              LicenseRef-PublicDomain
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".

category:             System
abi:                  47661b5bb59e165d679f4ead4494f9a1
exposed:              True
exposed-modules:      System.Environment.Executable
hidden-modules:       System.Environment.Executable.Linux
import-dirs:          /usr/lib/ghc-9.2.8/site-local/executable-path-0.0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-executable-path
hs-libraries:         HSexecutable-path-0.0.3.1-K1paw4SCDvS8wuNA9ltaVf
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-executable-path/html/executable-path.haddock

haddock-html:         /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-executable-path-0.0.3.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 executable-path
version:              0.0.3.1
visibility:           public
id:                   executable-path-0.0.3.1-IY8gYE4TcQeKZHM6USRszj
key:                  executable-path-0.0.3.1-IY8gYE4TcQeKZHM6USRszj
license:              LicenseRef-PublicDomain
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".

category:             System
abi:                  081d3069299f1b7f42224a620c65fa4f
exposed:              True
exposed-modules:      System.Environment.Executable
hidden-modules:       System.Environment.Executable.Linux
import-dirs:          /usr/lib/ghc-9.4.8/site-local/executable-path-0.0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/executable-path-0.0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-executable-path
hs-libraries:         HSexecutable-path-0.0.3.1-IY8gYE4TcQeKZHM6USRszj
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-executable-path/html/executable-path.haddock

haddock-html:         /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
